@@ -11,11 +11,15 @@
 """
 from mysql.connector import connect
 from mysql.connector.cursor_cext import CMySQLCursor
+from middleware_helper.network import filter_system_port_list
 
 
 class Mysql(object):
 
     def __init__(self, **mysql_params_map):
+        port = mysql_params_map.get("port")
+        if isinstance(port, list):
+            mysql_params_map["port"] = filter_system_port_list(data_port=port, default_port=6379)
         self.conn = connect(
             host=mysql_params_map.get("host"),
             user=mysql_params_map.get("user"),
